+++
title = "Empty Special Block"
description = "This post contains an empty Org Special Block."
tags = ["special-block", "empty"]
draft = false
+++

The empty Org Special Block is not exported at all.
